@@ -1,18 +1,17 @@
 /*
-@ @licstart  The following is the entire license notice for the
+@licstart  The following is the entire license notice for the
 JavaScript code in this file.
 
-Copyright (C) 1997-2017 by Dimitri van Heesch
+Copyright (C) 1997-2019 by Dimitri van Heesch
 
 This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
+it under the terms of version 2 of the GNU General Public License as published by
+the Free Software Foundation
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License along
 with this program; if not, write to the Free Software Foundation, Inc.,
@@ -66,6 +65,7 @@ var NAVTREE =
         [ "Code Blocks", "markdown.html#md_codeblock", null ],
         [ "Horizontal Rulers", "markdown.html#md_rulers", null ],
         [ "Emphasis", "markdown.html#md_emphasis", null ],
+        [ "Strikethrough", "markdown.html#md_strikethrough", null ],
         [ "code spans", "markdown.html#md_codespan", null ],
         [ "Links", "markdown.html#md_links", [
           [ "Inline Links", "markdown.html#md_inlinelinks", null ],
@@ -84,7 +84,7 @@ var NAVTREE =
         [ "Including Markdown files as pages", "markdown.html#md_page_header", null ],
         [ "Treatment of HTML blocks", "markdown.html#md_html_blocks", null ],
         [ "Code Block Indentation", "markdown.html#mddox_code_blocks", null ],
-        [ "Emphasis limits", "markdown.html#mddox_emph_spans", null ],
+        [ "Emphasis and strikethrough limits", "markdown.html#mddox_emph_spans", null ],
         [ "Code Spans Limits", "markdown.html#mddox_code_spans", null ],
         [ "Lists Extensions", "markdown.html#mddox_lists", null ],
         [ "Use of asterisks", "markdown.html#mddox_stars", null ],
@@ -134,7 +134,7 @@ var NAVTREE =
       [ "When I set EXTRACT_ALL to NO none of my functions are shown in the documentation.", "faq.html#faq_extract_all", null ],
       [ "My file with a custom extension is not parsed (properly) (anymore).", "faq.html#faq_ext_mapping", null ],
       [ "How can I make doxygen ignore some code fragment?", "faq.html#faq_code", null ],
-      [ "How can I change what is after the <code>#include</code> in the class documentation?", "faq.html#faq_code_inc", null ],
+      [ "How can I change what is after the #include in the class documentation?", "faq.html#faq_code_inc", null ],
       [ "How can I use tag files in combination with compressed HTML?", "faq.html#faq_chm", null ],
       [ "I don't like the quick index that is put above each HTML page, what do I do?", "faq.html#faq_html", null ],
       [ "The overall HTML output looks different, while I only wanted to use my own html header file", "faq.html#faq_html_header", null ],
@@ -143,7 +143,7 @@ var NAVTREE =
       [ "Doxygen automatically generates a link to the class MyClass somewhere in the running text.  How do I prevent that at a certain place?", "faq.html#faq_class", null ],
       [ "My favorite programming language is X. Can I still use doxygen?", "faq.html#faq_pgm_X", null ],
       [ "Help! I get the cryptic message \"input buffer overflow, can't enlarge buffer because scanner uses REJECT\"", "faq.html#faq_lex", null ],
-      [ "When running make in the latex dir I get \"TeX capacity exceeded\". Now what?", "faq.html#faq_latex", null ],
+      [ "When running make in the latex directory I get \"TeX capacity exceeded\". Now what?", "faq.html#faq_latex", null ],
       [ "Why are dependencies via STL classes not shown in the dot graphs?", "faq.html#faq_stl", null ],
       [ "I have problems getting the search engine to work with PHP5 and/or windows", "faq.html#faq_search", null ],
       [ "Can I configure doxygen from the command line?", "faq.html#faq_cmdline", null ],
@@ -188,13 +188,17 @@ var NAVTREE =
       [ "\\hidecallgraph", "commands.html#cmdhidecallgraph", null ],
       [ "\\callergraph", "commands.html#cmdcallergraph", null ],
       [ "\\hidecallergraph", "commands.html#cmdhidecallergraph", null ],
+      [ "\\showrefby", "commands.html#cmdshowrefby", null ],
+      [ "\\hiderefby", "commands.html#cmdhiderefby", null ],
+      [ "\\showrefs", "commands.html#cmdshowrefs", null ],
+      [ "\\hiderefs", "commands.html#cmdhiderefs", null ],
       [ "\\category <name> [<header-file>] [<header-name>]", "commands.html#cmdcategory", null ],
       [ "\\class <name> [<header-file>] [<header-name>]", "commands.html#cmdclass", null ],
       [ "\\def <name>", "commands.html#cmddef", null ],
       [ "\\defgroup <name> (group title)", "commands.html#cmddefgroup", null ],
       [ "\\dir [<path fragment>]", "commands.html#cmddir", null ],
       [ "\\enum <name>", "commands.html#cmdenum", null ],
-      [ "\\example <file-name>", "commands.html#cmdexample", null ],
+      [ "\\example['{lineno}'] <file-name>", "commands.html#cmdexample", null ],
       [ "\\endinternal", "commands.html#cmdendinternal", null ],
       [ "\\extends <name>", "commands.html#cmdextends", null ],
       [ "\\file [<name>]", "commands.html#cmdfile", null ],
@@ -255,7 +259,7 @@ var NAVTREE =
       [ "\\invariant { description of invariant }", "commands.html#cmdinvariant", null ],
       [ "\\note { text }", "commands.html#cmdnote", null ],
       [ "\\par [(paragraph title)] { paragraph }", "commands.html#cmdpar", null ],
-      [ "\\param [(dir)] <parameter-name> { parameter description }", "commands.html#cmdparam", null ],
+      [ "\\param '['dir']' <parameter-name> { parameter description }", "commands.html#cmdparam", null ],
       [ "\\parblock", "commands.html#cmdparblock", null ],
       [ "\\endparblock", "commands.html#cmdendparblock", null ],
       [ "\\tparam <template-parameter-name> { description }", "commands.html#cmdtparam", null ],
@@ -288,35 +292,36 @@ var NAVTREE =
       [ "\\secreflist", "commands.html#cmdsecreflist", null ],
       [ "\\endsecreflist", "commands.html#cmdendsecreflist", null ],
       [ "\\subpage <name> [\"(text)\"]", "commands.html#cmdsubpage", null ],
-      [ "\\tableofcontents", "commands.html#cmdtableofcontents", null ],
+      [ "\\tableofcontents['{'[option[:level]][,option[:level]]*'}']", "commands.html#cmdtableofcontents", null ],
       [ "\\section <section-name> (section title)", "commands.html#cmdsection", null ],
       [ "\\subsection <subsection-name> (subsection title)", "commands.html#cmdsubsection", null ],
       [ "\\subsubsection <subsubsection-name> (subsubsection title)", "commands.html#cmdsubsubsection", null ],
       [ "\\paragraph <paragraph-name> (paragraph title)", "commands.html#cmdparagraph", null ],
-      [ "\\dontinclude <file-name>", "commands.html#cmddontinclude", null ],
-      [ "\\include <file-name>", "commands.html#cmdinclude", null ],
+      [ "\\dontinclude['{lineno}'] <file-name>", "commands.html#cmddontinclude", null ],
+      [ "\\include['{'option'}'] <file-name>", "commands.html#cmdinclude", null ],
       [ "\\includelineno <file-name>", "commands.html#cmdincludelineno", null ],
       [ "\\includedoc <file-name>", "commands.html#cmdincludedoc", null ],
       [ "\\line ( pattern )", "commands.html#cmdline", null ],
       [ "\\skip ( pattern )", "commands.html#cmdskip", null ],
       [ "\\skipline ( pattern )", "commands.html#cmdskipline", null ],
-      [ "\\snippet <file-name> ( block_id )", "commands.html#cmdsnippet", null ],
+      [ "\\snippet['{'option'}'] <file-name> ( block_id )", "commands.html#cmdsnippet", null ],
       [ "\\snippetlineno <file-name> ( block_id )", "commands.html#cmdsnippetlineno", null ],
       [ "\\snippetdoc <file-name> ( block_id )", "commands.html#cmdsnippetdoc", null ],
       [ "\\until ( pattern )", "commands.html#cmduntil", null ],
       [ "\\verbinclude <file-name>", "commands.html#cmdverbinclude", null ],
-      [ "\\htmlinclude <file-name>", "commands.html#cmdhtmlinclude", null ],
+      [ "\\htmlinclude [\"[block]\"] <file-name>", "commands.html#cmdhtmlinclude", null ],
       [ "\\latexinclude <file-name>", "commands.html#cmdlatexinclude", null ],
       [ "\\a <word>", "commands.html#cmda", null ],
       [ "\\arg { item-description }", "commands.html#cmdarg", null ],
       [ "\\b <word>", "commands.html#cmdb", null ],
       [ "\\c <word>", "commands.html#cmdc", null ],
-      [ "\\code [ '{'<word>'}']", "commands.html#cmdcode", null ],
+      [ "\\code['{'<word>'}']", "commands.html#cmdcode", null ],
       [ "\\copydoc <link-object>", "commands.html#cmdcopydoc", null ],
       [ "\\copybrief <link-object>", "commands.html#cmdcopybrief", null ],
       [ "\\copydetails <link-object>", "commands.html#cmdcopydetails", null ],
       [ "\\docbookonly", "commands.html#cmddocbookonly", null ],
       [ "\\dot [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmddot", null ],
+      [ "\\emoji \"name\"", "commands.html#cmdemoji", null ],
       [ "\\msc [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdmsc", null ],
       [ "\\startuml [{file}] [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdstartuml", null ],
       [ "\\dotfile <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmddotfile", null ],
@@ -341,7 +346,7 @@ var NAVTREE =
       [ "\\f{environment}{", "commands.html#cmdfcurlyopen", null ],
       [ "\\f}", "commands.html#cmdfcurlyclose", null ],
       [ "\\htmlonly [\"[block]\"]", "commands.html#cmdhtmlonly", null ],
-      [ "\\image <format> <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdimage", null ],
+      [ "\\image['{'option'}'] <format> <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdimage", null ],
       [ "\\latexonly", "commands.html#cmdlatexonly", null ],
       [ "\\manonly", "commands.html#cmdmanonly", null ],
       [ "\\li { item-description }", "commands.html#cmdli", null ],
@@ -361,6 +366,7 @@ var NAVTREE =
       [ "\\%", "commands.html#cmdperc", null ],
       [ "\\\"", "commands.html#cmdquot", null ],
       [ "\\.", "commands.html#cmdchardot", null ],
+      [ "\\=", "commands.html#cmdeq", null ],
       [ "\\::", "commands.html#cmddcolon", null ],
       [ "\\|", "commands.html#cmdpipe", null ],
       [ "\\--", "commands.html#cmdndash", null ],
@@ -368,6 +374,10 @@ var NAVTREE =
     ] ],
     [ "HTML Commands", "htmlcmds.html", null ],
     [ "XML Commands", "xmlcmds.html", null ],
+    [ "Emoji support", "emojisup.html", [
+      [ "Representation", "emojisup.html#emojirep", null ],
+      [ "Emoji image retrieval", "emojisup.html#emojiimage", null ]
+    ] ],
     [ "Internationalization", "langhowto.html", null ],
     [ "Perl Module Output", "perlmod.html", [
       [ "Usage", "perlmod.html#using_perlmod_fmt", null ],
@@ -381,6 +391,8 @@ var NAVTREE =
     [ "Doxygen's Internals", "arch.html", null ],
     [ "Changelog", "changelog.html", [
       [ "1.8 Series", "changelog.html#log_1_8", [
+        [ "Release 1.8.16", "changelog.html#log_1_8_16", null ],
+        [ "Release 1.8.15", "changelog.html#log_1_8_15", null ],
         [ "Release 1.8.14", "changelog.html#log_1_8_14", null ],
         [ "Release 1.8.13", "changelog.html#log_1_8_13", null ],
         [ "Release 1.8.12", "changelog.html#log_1_8_12", null ],
@@ -402,7 +414,12 @@ var NAVTREE =
         [ "Release 1.8.0", "changelog.html#log_1_8_0", null ]
       ] ],
       [ "1.7 Series", "changelog.html#log_1_7", null ],
-      [ "1.6 Series", "changelog.html#log_1_6", null ]
+      [ "1.6 Series", "changelog.html#log_1_6", null ],
+      [ "1.5 Series", "changelog.html#log_1_5", null ],
+      [ "1.4 Series", "changelog.html#log_1_4", null ],
+      [ "1.3 Series", "changelog.html#log_1_3", null ],
+      [ "1.2 Series", "changelog.html#log_1_2", null ],
+      [ "1.1 Series", "changelog.html#log_1_1", null ]
     ] ]
   ] ]
 ];
@@ -410,7 +427,7 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "arch.html",
-"docblocks.html#docexamples"
+"custcmd.html#custcmd_nesting"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
