@@ -1,5 +1,19 @@
 var NAVTREEINDEX1 =
 {
+"custcmd.html#custcmd_nesting":[14,2],
+"custcmd.html#custcmd_simple":[14,0],
+"customize.html":[13],
+"customize.html#layout":[13,1],
+"customize.html#minor_tweaks":[13,0],
+"customize.html#minor_tweaks_colors":[13,0,0],
+"customize.html#minor_tweaks_dynsection":[13,0,2],
+"customize.html#minor_tweaks_header_css":[13,0,3],
+"customize.html#minor_tweaks_treeview":[13,0,1],
+"customize.html#xmlgenerator":[13,2],
+"diagrams.html":[8],
+"docblocks.html":[2],
+"docblocks.html#cppblock":[2,0,0],
+"docblocks.html#docexamples":[2,0,0,1],
 "docblocks.html#docstructure":[2,1],
 "docblocks.html#fortranblocks":[2,0,3],
 "docblocks.html#memberdoc":[2,0,0,0],
@@ -11,6 +25,9 @@ var NAVTREEINDEX1 =
 "doxygen_usage.html":[19],
 "doxygen_usage.html#doxygen_finetune":[19,0],
 "doxywizard_usage.html":[20],
+"emojisup.html":[25],
+"emojisup.html#emojiimage":[25,1],
+"emojisup.html#emojirep":[25,0],
 "external.html":[15],
 "extsearch.html":[12,0],
 "extsearch.html#extsearch_api":[12,0,3],
@@ -56,30 +73,31 @@ var NAVTREEINDEX1 =
 "install.html#install_bin_windows":[0,3],
 "install.html#install_src_unix":[0,0],
 "install.html#install_src_windows":[0,2],
-"langhowto.html":[25],
+"langhowto.html":[26],
 "lists.html":[4],
 "markdown.html":[3],
 "markdown.html#markdown_debug":[3,3],
 "markdown.html#markdown_dox":[3,2],
 "markdown.html#markdown_extra":[3,1],
 "markdown.html#markdown_std":[3,0],
-"markdown.html#md_autolink":[3,0,10],
+"markdown.html#md_autolink":[3,0,11],
 "markdown.html#md_blockquotes":[3,0,2],
 "markdown.html#md_codeblock":[3,0,4],
-"markdown.html#md_codespan":[3,0,7],
+"markdown.html#md_codespan":[3,0,8],
 "markdown.html#md_emphasis":[3,0,6],
 "markdown.html#md_fenced":[3,1,2],
 "markdown.html#md_header_id":[3,1,3],
 "markdown.html#md_headers":[3,0,1],
 "markdown.html#md_html_blocks":[3,2,1],
-"markdown.html#md_images":[3,0,9],
-"markdown.html#md_inlinelinks":[3,0,8,0],
-"markdown.html#md_links":[3,0,8],
+"markdown.html#md_images":[3,0,10],
+"markdown.html#md_inlinelinks":[3,0,9,0],
+"markdown.html#md_links":[3,0,9],
 "markdown.html#md_lists":[3,0,3],
 "markdown.html#md_page_header":[3,2,0],
 "markdown.html#md_para":[3,0,0],
-"markdown.html#md_reflinks":[3,0,8,1],
+"markdown.html#md_reflinks":[3,0,9,1],
 "markdown.html#md_rulers":[3,0,5],
+"markdown.html#md_strikethrough":[3,0,7],
 "markdown.html#md_tables":[3,1,1],
 "markdown.html#md_toc":[3,1,0],
 "markdown.html#mddox_code_blocks":[3,2,2],
@@ -90,13 +108,13 @@ var NAVTREEINDEX1 =
 "markdown.html#mddox_stars":[3,2,6],
 "output.html":[11],
 "pages.html":[],
-"perlmod.html":[26],
-"perlmod.html#doxydocs_format":[26,2],
-"perlmod.html#doxymodel_format":[26,3],
-"perlmod.html#perlmod_latex":[26,1],
-"perlmod.html#pm_pdf_gen":[26,1,0],
-"perlmod.html#using_perlmod_fmt":[26,0],
-"perlmod_tree.html":[27],
+"perlmod.html":[27],
+"perlmod.html#doxydocs_format":[27,2],
+"perlmod.html#doxymodel_format":[27,3],
+"perlmod.html#perlmod_latex":[27,1],
+"perlmod.html#pm_pdf_gen":[27,1,0],
+"perlmod.html#using_perlmod_fmt":[27,0],
+"perlmod_tree.html":[28],
 "preprocessing.html":[9],
 "searching.html":[12],
 "starting.html":[1],
